// SPDX-License-Identifier: GPL-2.0-only
/*
 * soc-acpi-intel-cnl-match.c - tables and support for CNL ACPI enumeration.
 *
 * Copyright (c) 2018, Intel Corporation.
 *
 */

#include <sound/soc-acpi.h>
#include <sound/soc-acpi-intel-match.h>

static struct snd_soc_acpi_codecs cnl_codecs = {
	.num_codecs = 1,
	.codecs = {"ESSX8336"}
};

struct snd_soc_acpi_mach snd_soc_acpi_intel_cnl_machines[] = {
	{
		.id = "ESSX8336",
		.drv_name = "sof-essx8336",
		.machine_quirk = snd_soc_acpi_codec_list,
		.quirk_data = &cnl_codecs,
		.sof_fw_filename = "sof-cnl.ri",
		.sof_tplg_filename = "graviton-n15i-k2.tplg",
	},
	{},
};

struct snd_soc_acpi_mach snd_soc_acpi_intel_cml_machines[] = {
	{
		.id = "ESSX8336",
		.drv_name = "sof-essx8336",
		.machine_quirk = snd_soc_acpi_codec_list,
		.quirk_data = &cnl_codecs,
		.sof_fw_filename = "sof-cml.ri",
		.sof_tplg_filename = "graviton-n15i-k2.tplg",
	},
	{},
};

EXPORT_SYMBOL_GPL(snd_soc_acpi_intel_cnl_machines);
EXPORT_SYMBOL_GPL(snd_soc_acpi_intel_cml_machines);

struct snd_soc_acpi_mach snd_soc_acpi_intel_adl_machines[] = {{}};
struct snd_soc_acpi_mach snd_soc_acpi_intel_jsl_machines[] = {{}};
struct snd_soc_acpi_mach snd_soc_acpi_intel_hda_machines[] = {{}};
struct snd_soc_acpi_mach snd_soc_acpi_intel_ehl_machines[] = {{}};
struct snd_soc_acpi_mach snd_soc_acpi_intel_tgl_machines[] = {{}};
struct snd_soc_acpi_mach snd_soc_acpi_intel_bxt_machines[] = {{}};
struct snd_soc_acpi_mach snd_soc_acpi_intel_glk_machines[] = {{}};
struct snd_soc_acpi_mach snd_soc_acpi_intel_icl_machines[] = {{}};
struct snd_soc_acpi_mach snd_soc_acpi_intel_cfl_machines[] = {{}};
struct snd_soc_acpi_mach snd_soc_acpi_intel_cfl_sdw_machines[] = {{}};
struct snd_soc_acpi_mach snd_soc_acpi_intel_cnl_sdw_machines[] = {{}};
struct snd_soc_acpi_mach snd_soc_acpi_intel_cml_sdw_machines[] = {{}};
struct snd_soc_acpi_mach snd_soc_acpi_intel_tgl_sdw_machines[] = {{}};
struct snd_soc_acpi_mach snd_soc_acpi_intel_adl_sdw_machines[] = {{}};
struct snd_soc_acpi_mach snd_soc_acpi_intel_icl_sdw_machines[] = {{}};
struct snd_soc_acpi_mach snd_soc_acpi_intel_baytrail_machines[] = {{}};
struct snd_soc_acpi_mach snd_soc_acpi_intel_cherrytrail_machines[] = {{}};
struct snd_soc_acpi_mach snd_soc_acpi_intel_haswell_machines[] = {{}};
struct snd_soc_acpi_mach snd_soc_acpi_intel_broadwell_machines[] = {{}};
struct snd_soc_acpi_mach snd_soc_acpi_intel_kbl_machines[] = {{}};
struct snd_soc_acpi_mach snd_soc_acpi_intel_skl_machines[] = {{}};

EXPORT_SYMBOL_GPL(snd_soc_acpi_intel_adl_machines);
EXPORT_SYMBOL_GPL(snd_soc_acpi_intel_jsl_machines);
EXPORT_SYMBOL_GPL(snd_soc_acpi_intel_hda_machines);
EXPORT_SYMBOL_GPL(snd_soc_acpi_intel_ehl_machines);
EXPORT_SYMBOL_GPL(snd_soc_acpi_intel_tgl_machines);
EXPORT_SYMBOL_GPL(snd_soc_acpi_intel_bxt_machines);
EXPORT_SYMBOL_GPL(snd_soc_acpi_intel_glk_machines);
EXPORT_SYMBOL_GPL(snd_soc_acpi_intel_icl_machines);
EXPORT_SYMBOL_GPL(snd_soc_acpi_intel_cfl_machines);
EXPORT_SYMBOL_GPL(snd_soc_acpi_intel_cfl_sdw_machines);
EXPORT_SYMBOL_GPL(snd_soc_acpi_intel_cnl_sdw_machines);
EXPORT_SYMBOL_GPL(snd_soc_acpi_intel_cml_sdw_machines);
EXPORT_SYMBOL_GPL(snd_soc_acpi_intel_tgl_sdw_machines);
EXPORT_SYMBOL_GPL(snd_soc_acpi_intel_adl_sdw_machines);
EXPORT_SYMBOL_GPL(snd_soc_acpi_intel_icl_sdw_machines);
EXPORT_SYMBOL_GPL(snd_soc_acpi_intel_baytrail_machines);
EXPORT_SYMBOL_GPL(snd_soc_acpi_intel_cherrytrail_machines);
EXPORT_SYMBOL_GPL(snd_soc_acpi_intel_haswell_machines);
EXPORT_SYMBOL_GPL(snd_soc_acpi_intel_broadwell_machines);
EXPORT_SYMBOL_GPL(snd_soc_acpi_intel_kbl_machines);
EXPORT_SYMBOL_GPL(snd_soc_acpi_intel_skl_machines);

MODULE_LICENSE("GPL v2");
MODULE_DESCRIPTION("Intel ACPI Match module");
